import * as React from 'react';
import { IHomeDetailsListProps } from './IHomeDetailsListProps';
import { Announced } from 'office-ui-fabric-react/lib/Announced';
import { TextField, ITextFieldStyles } from 'office-ui-fabric-react/lib/TextField';
import { DetailsList, DetailsListLayoutMode, Selection, IColumn } from 'office-ui-fabric-react/lib/DetailsList';
import { MarqueeSelection } from 'office-ui-fabric-react/lib/MarqueeSelection';
import { Fabric } from 'office-ui-fabric-react/lib/Fabric';
import { mergeStyles } from 'office-ui-fabric-react/lib/Styling';
import { DefaultButton, PrimaryButton } from '@microsoft/office-ui-fabric-react-bundle';
import { Panel, PanelType } from 'office-ui-fabric-react';



const exampleChildClass = mergeStyles({
  display: 'block',
  marginBottom: '10px',
});

const textFieldStyles: Partial<ITextFieldStyles> = { root: { maxWidth: '300px' } };

export interface IDetailsListBasicExampleItem {
  ID: number;
  name: string;
  category: string;
  amount: number;
}

export interface IDetailsListBasicExampleState {
  items: IDetailsListBasicExampleItem[];
  selectionDetails: string;
  itemsAux: IDetailsListBasicExampleItem[];
  showPanel: boolean;
}

export default class HomeDetailsList extends React.Component<IHomeDetailsListProps, IDetailsListBasicExampleState> {
  private _selection: Selection;
  private _allItems: IDetailsListBasicExampleItem[];
  private _columns: IColumn[];
  


  constructor(props: IHomeDetailsListProps) {
    super(props);

    this.state = {
      items:[
        {
          ID: 1,
          name: "Platano",
          category: "fruta",
          amount: 4,
        },
        {
          ID: 2,
          name: "Fresa",
          category: "fruta",
          amount: 3,
        },
        {
          ID: 3,
          name: "Pera",
          category: "fruta",
          amount: 2,
        },
        {
          ID: 1,
          name: "Brocolí",
          category: "verdura",
          amount: 5,
        }
  
      ],
      selectionDetails: '',
      itemsAux: [],
      showPanel: false
    };
      
    this._selection = new Selection({
      onSelectionChanged: () => this.setState({ selectionDetails: this._getSelectionDetails() }),
    });    

    this._columns = [
      { key: 'column1', name: 'ID', fieldName: 'ID', minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column2', name: 'Name', fieldName: 'name', minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column3', name: 'Category', fieldName: 'category', minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column4', name: 'Amount', fieldName: 'amount', minWidth: 100, maxWidth: 200, isResizable: true },
    ];

  }

  componentDidMount() {
      this.setState({ itemsAux: this.state.items });
  }

  public render(): React.ReactElement<IHomeDetailsListProps> {
    const { items, itemsAux, selectionDetails } = this.state;

    
    function _alertClicked(): void {
      alert('Clicked');
    }
    
    

    return (
      <Fabric>
        <div className={exampleChildClass}>{selectionDetails}</div>
        <Announced message={selectionDetails} />
        <TextField
          className={exampleChildClass}
          label="Filter by name:"
          onChange={this._onFilter}
          styles={textFieldStyles}
        />
        <Announced message={`Number of items after filter applied: ${items.length}.`} />
        <MarqueeSelection selection={this._selection}>
          <DetailsList
            items={itemsAux}
            columns={this._columns}
            setKey="set"
            layoutMode={DetailsListLayoutMode.justified}
            selection={this._selection}
            selectionPreservedOnEmptyClick={true}
            ariaLabelForSelectionColumn="Toggle selection"
            ariaLabelForSelectAllCheckbox="Toggle selection for all items"
            checkButtonAriaLabel="Row checkbox"
            onItemInvoked={this._onItemInvoked}
          />
          <br />
          
          <div>
          <PrimaryButton
          secondaryText='Opens the Sample Panel'
          onClick={ this._onShowPanel }
          text='Añadir productos'
        />
        <Panel
          isOpen={ this.state.showPanel }
          type={ PanelType.medium }
          onDismiss={ this._onClosePanel }
          isFooterAtBottom={ true }
          headerText='Panel with footer at bottom'
          closeButtonAriaLabel='Close'
          onRenderFooterContent={ this._onRenderFooterContent }
        >
          <span>Content goes here.</span>
        </Panel>
          </div>
        </MarqueeSelection>
      </Fabric>
    );
  }

  private _onShowPanel = () => {
    this.setState({ showPanel: true });
  }
  private _onClosePanel = () => {
    this.setState({ showPanel: false });
  }

  private _onRenderFooterContent = (): JSX.Element => {
    return (
      <div>
        <PrimaryButton
          onClick={ this._onClosePanel }
          style={ { 'marginRight': '8px' } }
        >
          Save
        </PrimaryButton>
        <DefaultButton
          onClick={ this._onClosePanel }
        >
          Cancel
        </DefaultButton>
      </div>
    );
  }

  private _getSelectionDetails(): string {
    const selectionCount = this._selection.getSelectedCount();

    switch (selectionCount) {
      case 0:
        return 'No items selected';
      case 1:
        return '1 item selected: ' + (this._selection.getSelection()[0] as IDetailsListBasicExampleItem).name;
      default:
        return `${selectionCount} items selected`;
    }
  }

  private _onFilter = (ev: React.FormEvent<HTMLInputElement | HTMLTextAreaElement>, text: string): void => {

    this.setState({
      
      itemsAux: text ? this.state.items.filter(i => i.name.toLowerCase().indexOf(text) > -1) : this.state.items,

     
    });
    //alert(`que es lo que aparece: ${text} ${this.state.items.length}`);
  }

  private _onItemInvoked = (item: IDetailsListBasicExampleItem): void => {
    alert(`Item invoked: ${item.name}`);
  }
}

